@@ -12,3 +12,8 @@ class ARBException(AuthnetException):
     """Authorize.net ARB base exception class."""
     
     pass
+
+class CIMException(AuthnetException):
+    """Authorize.net CIM base exception class."""
+    
+    pass
